SingleThreadCell

Struct SingleThreadCell 

pub struct SingleThreadCell<T> { /* private fields */ }
A mutable memory location. Can only be accessed by the owner thread.

If you access the cell from a different thread, the thread will be panicked.

Implementations

Source

impl<T> SingleThreadCell<T>

pub fn new(val: T) -> Self

Creates a new Cell containing the given value.

The owner thread will be the same as the caller thread.

pub fn set(&self, value: T)

Set the contained value

Panics

This function will panic if access from different thread

pub fn replace(&self, value: T) -> T

Replace the contained value, and return the old contained value.

Panics

This function will panic if access from different thread

Source

impl<T: Copy> SingleThreadCell<T>

pub fn get(&self) -> T

Returns a copy of the contained value.